sqltriples.Types

Package sqltriples :: Module Types |
[show private | hide private]
[frames | no frames]

## Module sqltriples.Types

    Special data types inheriting from the unicode type in order to provide
    interoperability with rdflib.

    Copyright (C) 2006, 2007 Paul Boddie <paul@boddie.org.uk>

    This program is free software; you can redistribute it and/or modify it under
    the terms of the GNU Lesser General Public License as published by the Free
    Software Foundation; either version 3 of the License, or (at your option) any
    later version.

    This program is distributed in the hope that it will be useful, but WITHOUT
    ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
    FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
    details.

    You should have received a copy of the GNU Lesser General Public License along
    with this program.  If not, see <http://www.gnu.org/licenses/>.

Classes
`AbstractExpression` | An abstract expression class providing tuple infrastructure.
`BNode` | A BNode compatible with the rdflib class of the same name.
`Defined` | A class indicating a value defined for a particular relation.
`Expression` | An general class wrapping an expression and associated values.
`Literal` | A literal compatible with the rdflib class of the same name.
`LiteralExpression` | An expression acting as a Literal.
`Namespace` | A namespace compatible with the rdflib class of the same name.
`Pattern` | A pattern which may be unpacked like a tuple.
`Special` | A special abstract class inheriting from the unicode type.
`URIRef` | An URI reference compatible with the rdflib class of the same name.
`URIRefExpression` | An expression acting as a URIRef.

Variable Summary
`tuple` | `ALL` = `(None, None, None)`
`Namespace` | `RDFNS` = `Namespace(u'http://www.w3.org/1999/02/22-rdf-syn...`
`Namespace` | `TYPE` = `Namespace(u'http://www.w3.org/1999/02/22-rdf-synt...`

Variable Details

    ### ALL Type: `tuple` Value:
        (None, None, None)

    ### RDFNS Type: `Namespace` Value:
        Namespace(u'http://www.w3.org/1999/02/22-rdf-syntax-ns#')

    ### TYPE Type: `Namespace` Value:
        Namespace(u'http://www.w3.org/1999/02/22-rdf-syntax-ns#type')

Generated by Epydoc 2.1 on Sat Jul 7 23:24:47 2007 | http://epydoc.sf.net